@@ -68,16 +68,6 @@
 # define _X_EXPORT /**/
 #endif
 
-#ifndef HAVE_CONFIG_H
-# if (FREETYPE_MAJOR > 2 ||						    \
-      (FREETYPE_MAJOR == 2 && (FREETYPE_MINOR > 1 ||			    \
-			       (FREETYPE_MINOR == 1 && FREETYPE_PATCH >= 5))))
-#  define HAVE_FT_BITMAP_SIZE_Y_PPEM 1
-# else
-#  define HAVE_FT_BITMAP_SIZE_Y_PPEM 0
-# endif
-#endif
-
 typedef struct _XftMatcher {
     char    *object;
     double  (*compare) (char *object, FcValue value1, FcValue value2);
@@ -255,6 +245,7 @@ typedef struct _XftDisplayInfo {
     XExtCodes		    *codes;
     FcPattern		    *defaults;
     FcBool		    hasRender;
+    FcBool		    hasSolid;
     XftFont		    *fonts;
     XRenderPictFormat	    *solidFormat;
     unsigned long	    glyph_memory;
@@ -437,8 +428,6 @@ XftListFontsPatternObjects (Display	    *dpy,
 			    FcObjectSet    *os);
 
 /* xftname.c */
-void
-_XftNameInit (void);
 
 /* xftrender.c */
 
