@@ -55,10 +55,10 @@ XftGlyphRender (Display		*dpy,
     unsigned int    char_local[NUM_LOCAL];
     unsigned int    *chars;
     FcBool	    glyphs_loaded;
-    
+
     if (!font->format)
 	return;
-    
+
     /*
      * Load missing glyphs
      */
@@ -75,7 +75,7 @@ XftGlyphRender (Display		*dpy,
     }
     if (nmissing)
 	XftFontLoadGlyphs (dpy, pub, FcTrue, missing, nmissing);
-    
+
     if (!font->glyphset)
 	goto bail1;
     if (max < 0x100)
@@ -96,7 +96,7 @@ XftGlyphRender (Display		*dpy,
     chars = char_local;
     if (nglyphs * size > sizeof (char_local))
     {
-	chars = malloc (nglyphs * size);
+	chars = malloc ((size_t)(nglyphs * size));
 	if (!chars)
 	    goto bail1;
     }
@@ -111,7 +111,7 @@ XftGlyphRender (Display		*dpy,
 	switch (width) {
 	case 1: char8[i] = (char) wire; break;
 	case 2: char16[i] = (unsigned short) wire; break;
-	case 4: char32[i] = (unsigned long) wire; break;
+	case 4: char32[i] = (unsigned int) wire; break;
 	}
     }
     switch (width) {
@@ -169,12 +169,12 @@ XftGlyphSpecRender (Display		    *dpy,
     FcBool	    glyphs_loaded;
     int		    nelt;
     int		    x, y;
-    
+
     if (!font->format)
 	return;
     if (!nglyphs)
 	return;
-    
+
     /*
      * Load missing glyphs
      */
@@ -192,7 +192,7 @@ XftGlyphSpecRender (Display		    *dpy,
     }
     if (nmissing)
 	XftFontLoadGlyphs (dpy, pub, FcTrue, missing, nmissing);
-    
+
     if (!font->glyphset)
 	goto bail1;
 
@@ -217,14 +217,14 @@ XftGlyphSpecRender (Display		    *dpy,
     chars = char_local;
     if (nglyphs * size > NUM_LOCAL)
     {
-	chars = malloc (nglyphs * size);
+	chars = malloc ((size_t)(nglyphs * size));
 	if (!chars)
 	    goto bail1;
     }
     char8 = (char *) chars;
     char16 = (unsigned short *) chars;
     char32 = (unsigned int *) chars;
-    
+
     /*
      * Compute the number of glyph elts needed
      */
@@ -249,7 +249,7 @@ XftGlyphSpecRender (Display		    *dpy,
 	/* Substitute default for non-existant glyphs */
 	if (g >= font->num_glyphs || !font->glyphs[g])
 	    g = 0;
-	/* 
+	/*
 	 * check to see if the glyph is placed where it would
 	 * fall using the normal spacing
 	 */
@@ -269,7 +269,7 @@ XftGlyphSpecRender (Display		    *dpy,
     elts = elts_local;
     if (nelt > NUM_ELT_LOCAL)
     {
-	elts = malloc (nelt * sizeof (XGlyphElt8));
+	elts = malloc ((size_t)nelt * sizeof (XGlyphElt8));
 	if (!elts)
 	    goto bail2;
     }
@@ -354,7 +354,7 @@ XftCharSpecRender (Display		*dpy,
 		   Picture		src,
 		   XftFont		*pub,
 		   Picture		dst,
-		   int			srcx, 
+		   int			srcx,
 		   int			srcy,
 		   _Xconst XftCharSpec	*chars,
 		   int			len)
@@ -366,7 +366,7 @@ XftCharSpecRender (Display		*dpy,
 	glyphs = glyphs_local;
     else
     {
-	glyphs = malloc (len * sizeof (XftGlyphSpec));
+	glyphs = malloc ((size_t)len * sizeof (XftGlyphSpec));
 	if (!glyphs)
 	    return;
     }
@@ -395,8 +395,8 @@ XftCharSpecRender (Display		*dpy,
 static XRenderPictFormat *
 XftPreferFormat (Display *dpy, XRenderPictFormat *a, XRenderPictFormat *b)
 {
-    XRenderPictFormat	*prefer = 0;
-    
+    XRenderPictFormat	*prefer = NULL;
+
     if (a == b)
 	prefer = a;
     else if (XftIsARGBFormat(a) != XftIsARGBFormat(b))
@@ -439,10 +439,10 @@ XftGlyphFontSpecRender (Display			    *dpy,
     FcBool	    glyphs_loaded;
     int		    nelt;
     int		    x, y;
-    
+
     if (!nglyphs)
 	return;
-    
+
     /*
      * Load missing glyphs.  Have to load them
      * one at a time in case the font changes
@@ -467,7 +467,7 @@ XftGlyphFontSpecRender (Display			    *dpy,
 	if (!font->glyphset)
 	    goto bail1;
     }
-    
+
     /*
      * See what encoding size is needed
      */
@@ -489,19 +489,19 @@ XftGlyphFontSpecRender (Display			    *dpy,
     chars = char_local;
     if (nglyphs * size > NUM_LOCAL)
     {
-	chars = malloc (nglyphs * size);
+	chars = malloc ((size_t)(nglyphs * size));
 	if (!chars)
 	    goto bail1;
     }
     char8 = (char *) chars;
     char16 = (unsigned short *) chars;
     char32 = (unsigned int *) chars;
-    
+
     /*
      * Compute the number of glyph elts needed
      */
     nelt = 1;
-    firstFont = 0;
+    firstFont = NULL;
     for (i = 0; i < nglyphs; i++)
     {
 	XftFont	    *pub = glyphs[i].font;
@@ -522,7 +522,7 @@ XftGlyphFontSpecRender (Display			    *dpy,
     format = firstFont->format;
     x = glyphs[i].x + glyph->metrics.xOff;
     y = glyphs[i].y + glyph->metrics.yOff;
-    prevPublic = 0;
+    prevPublic = NULL;
     while (++i < nglyphs)
     {
 	XftFont	    *pub = glyphs[i].font;
@@ -531,7 +531,7 @@ XftGlyphFontSpecRender (Display			    *dpy,
 	/* Substitute default for non-existant glyphs */
 	if (g >= font->num_glyphs || !font->glyphs[g])
 	    g = 0;
-	/* 
+	/*
 	 * check to see if the glyph is placed where it would
 	 * fall using the normal spacing
 	 */
@@ -554,7 +554,7 @@ XftGlyphFontSpecRender (Display			    *dpy,
     elts = elts_local;
     if (nelt > NUM_ELT_LOCAL)
     {
-	elts = malloc (nelt * sizeof (XGlyphElt8));
+	elts = malloc ((size_t)nelt * sizeof (XGlyphElt8));
 	if (!elts)
 	    goto bail2;
     }
@@ -566,12 +566,12 @@ XftGlyphFontSpecRender (Display			    *dpy,
     x = y = 0;
     n = 0;
     j = 0;
-    prevPublic = 0;
+    prevPublic = NULL;
     for (i = 0; i < nglyphs; i++)
     {
 	XftFont	    *pub = glyphs[i].font;
 	XftFontInt  *font = (XftFontInt *) pub;
-	
+
 	g = glyphs[i].glyph;
 	/* Substitute default for non-existant glyphs */
 	if (g >= font->num_glyphs || !font->glyphs[g])
@@ -656,7 +656,7 @@ XftCharFontSpecRender (Display			*dpy,
 	glyphs = glyphs_local;
     else
     {
-	glyphs = malloc (len * sizeof (XftGlyphFontSpec));
+	glyphs = malloc ((size_t)len * sizeof (XftGlyphFontSpec));
 	if (!glyphs)
 	    return;
     }
@@ -693,13 +693,13 @@ XftTextRender8 (Display		*dpy,
 	glyphs = glyphs_local;
     else
     {
-	glyphs = malloc (len * sizeof (FT_UInt));
+	glyphs = malloc ((size_t)len * sizeof (FT_UInt));
 	if (!glyphs)
 	    return;
     }
     for (i = 0; i < len; i++)
 	glyphs[i] = XftCharIndex (dpy, pub, string[i]);
-    XftGlyphRender (dpy, op, src, pub, dst, 
+    XftGlyphRender (dpy, op, src, pub, dst,
 		     srcx, srcy, x, y, glyphs, len);
     if (glyphs != glyphs_local)
 	free (glyphs);
@@ -725,13 +725,13 @@ XftTextRender16 (Display	    *dpy,
 	glyphs = glyphs_local;
     else
     {
-	glyphs = malloc (len * sizeof (FT_UInt));
+	glyphs = malloc ((size_t)len * sizeof (FT_UInt));
 	if (!glyphs)
 	    return;
     }
     for (i = 0; i < len; i++)
 	glyphs[i] = XftCharIndex (dpy, pub, string[i]);
-    XftGlyphRender (dpy, op, src, pub, dst, 
+    XftGlyphRender (dpy, op, src, pub, dst,
 		     srcx, srcy, x, y, glyphs, len);
     if (glyphs != glyphs_local)
 	free (glyphs);
@@ -757,14 +757,14 @@ XftTextRender16BE (Display	    *dpy,
 	glyphs = glyphs_local;
     else
     {
-	glyphs = malloc (len * sizeof (FT_UInt));
+	glyphs = malloc ((size_t)len * sizeof (FT_UInt));
 	if (!glyphs)
 	    return;
     }
     for (i = 0; i < len; i++)
-	glyphs[i] = XftCharIndex (dpy, pub, 
-				  (string[i*2]<<8) | string[i*2+1]);
-    XftGlyphRender (dpy, op, src, pub, dst, 
+	glyphs[i] = XftCharIndex (dpy, pub,
+				  (FcChar32)((string[i*2]<<8) | string[i*2+1]));
+    XftGlyphRender (dpy, op, src, pub, dst,
 		     srcx, srcy, x, y, glyphs, len);
     if (glyphs != glyphs_local)
 	free (glyphs);
@@ -790,14 +790,14 @@ XftTextRender16LE (Display	    *dpy,
 	glyphs = glyphs_local;
     else
     {
-	glyphs = malloc (len * sizeof (FT_UInt));
+	glyphs = malloc ((size_t)len * sizeof (FT_UInt));
 	if (!glyphs)
 	    return;
     }
     for (i = 0; i < len; i++)
-	glyphs[i] = XftCharIndex (dpy, pub, 
-				  string[i*2] | (string[i*2+1]<<8));
-    XftGlyphRender (dpy, op, src, pub, dst, 
+	glyphs[i] = XftCharIndex (dpy, pub,
+				  (FcChar32)(string[i*2] | (string[i*2+1]<<8)));
+    XftGlyphRender (dpy, op, src, pub, dst,
 		     srcx, srcy, x, y, glyphs, len);
     if (glyphs != glyphs_local)
 	free (glyphs);
@@ -823,13 +823,13 @@ XftTextRender32 (Display	    *dpy,
 	glyphs = glyphs_local;
     else
     {
-	glyphs = malloc (len * sizeof (FT_UInt));
+	glyphs = malloc ((size_t)len * sizeof (FT_UInt));
 	if (!glyphs)
 	    return;
     }
     for (i = 0; i < len; i++)
 	glyphs[i] = XftCharIndex (dpy, pub, string[i]);
-    XftGlyphRender (dpy, op, src, pub, dst, 
+    XftGlyphRender (dpy, op, src, pub, dst,
 		     srcx, srcy, x, y, glyphs, len);
     if (glyphs != glyphs_local)
 	free (glyphs);
@@ -855,17 +855,17 @@ XftTextRender32BE (Display	    *dpy,
 	glyphs = glyphs_local;
     else
     {
-	glyphs = malloc (len * sizeof (FT_UInt));
+	glyphs = malloc ((size_t)len * sizeof (FT_UInt));
 	if (!glyphs)
 	    return;
     }
     for (i = 0; i < len; i++)
-	glyphs[i] = XftCharIndex (dpy, pub, 
-				  (string[i*4] << 24) |
-				  (string[i*4+1] << 16) |
-				  (string[i*4+2] << 8) |
-				  (string[i*4+3]));
-    XftGlyphRender (dpy, op, src, pub, dst, 
+	glyphs[i] = XftCharIndex (dpy, pub,
+				  (FcChar32)((string[i*4] << 24) |
+					     (string[i*4+1] << 16) |
+					     (string[i*4+2] << 8) |
+					     (string[i*4+3])));
+    XftGlyphRender (dpy, op, src, pub, dst,
 		     srcx, srcy, x, y, glyphs, len);
     if (glyphs != glyphs_local)
 	free (glyphs);
@@ -891,17 +891,17 @@ XftTextRender32LE (Display	    *dpy,
 	glyphs = glyphs_local;
     else
     {
-	glyphs = malloc (len * sizeof (FT_UInt));
+	glyphs = malloc ((size_t)len * sizeof (FT_UInt));
 	if (!glyphs)
 	    return;
     }
     for (i = 0; i < len; i++)
-	glyphs[i] = XftCharIndex (dpy, pub, 
-				  (string[i*4]) |
-				  (string[i*4+1] << 8) |
-				  (string[i*4+2] << 16) |
-				  (string[i*4+3] << 24));
-    XftGlyphRender (dpy, op, src, pub, dst, 
+	glyphs[i] = XftCharIndex (dpy, pub,
+				  (FcChar32)((string[i*4]) |
+					     (string[i*4+1] << 8) |
+					     (string[i*4+2] << 16) |
+					     (string[i*4+3] << 24)));
+    XftGlyphRender (dpy, op, src, pub, dst,
 		     srcx, srcy, x, y, glyphs, len);
     if (glyphs != glyphs_local)
 	free (glyphs);
@@ -933,14 +933,14 @@ XftTextRenderUtf8 (Display	    *dpy,
     {
 	if (i == size)
 	{
-	    glyphs_new = malloc (size * 2 * sizeof (FT_UInt));
+	    glyphs_new = malloc ((size_t)size * 2 * sizeof (FT_UInt));
 	    if (!glyphs_new)
 	    {
 		if (glyphs != glyphs_local)
 		    free (glyphs);
 		return;
 	    }
-	    memcpy (glyphs_new, glyphs, size * sizeof (FT_UInt));
+	    memcpy (glyphs_new, glyphs, (size_t)size * sizeof (FT_UInt));
 	    size *= 2;
 	    if (glyphs != glyphs_local)
 		free (glyphs);
@@ -983,14 +983,14 @@ XftTextRenderUtf16 (Display	    *dpy,
     {
 	if (i == size)
 	{
-	    glyphs_new = malloc (size * 2 * sizeof (FT_UInt));
+	    glyphs_new = malloc ((size_t)size * 2 * sizeof (FT_UInt));
 	    if (!glyphs_new)
 	    {
 		if (glyphs != glyphs_local)
 		    free (glyphs);
 		return;
 	    }
-	    memcpy (glyphs_new, glyphs, size * sizeof (FT_UInt));
+	    memcpy (glyphs_new, glyphs, (size_t)size * sizeof (FT_UInt));
 	    size *= 2;
 	    if (glyphs != glyphs_local)
 		free (glyphs);
